package Bundle::JONASBN;

$VERSION = '0.02';

1;

__END__

=pod

=head1 NAME

Bundle::JONASBN - Collection of modules often used by jonasbn

=head1 SYNOPSIS

    perl -MCPAN -e 'install Bundle::JONASBN'

=head1 CONTENTS

=over

=item * L<AppConfig>

=item * L<Cwd>

=item * L<DBI>

=item * L<Data::Dumper>

=item * L<Date::Calc>

=item * L<Devel::Cover>

=item * L<Error>

=item * L<ExtUtils::Install>, 1.47

=item * L<File::Path>

=item * L<File::Slurp>

=item * L<Hash::Merge>

=item * L<JSON>

=item * L<List::MoreUtils>

=item * L<Module::Build>, 0.35

=item * L<Module::Info::File>

=item * L<Module::Load>

=item * L<Params::Validate>, 0.85

=item * L<Perl::Tidy>

=item * L<Spreadsheet::WriteExcel>

=item * L<Template>

=item * L<Test::Exception>

=item * L<Test::Kwalitee>

=item * L<Test::MockObject::Extends>

=item * L<Test::More>

=item * L<Test::Perl::Critic>

=item * L<Test::Pod>, 1.14

=item * L<Test::Pod::Coverage>, 1.04

=item * L<Test::Prereq>

=item * L<Tie::IxHash>

=item * L<WWW::Mechanize>

=item * L<WWW::Mechanize::Cached>

=item * L<XML::Simple>

=item * L<YAML>

=back

=head1 SEE ALSO

=over

=item * L<Bundle::COG>

=back

=head1 AUTHOR

Jonas B. Nielsen (jonasbn), C<< <jonasbn@cpan.org> >>

=head1 COPYRIGHT & LICENSE

Copyright 2009 Jonas B. Nielsen (jonasbn), All Rights Reserved.

This program is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=cut
